/* Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.importer.sinfo.importitem;

import java.util.List;

import org.dive4elements.river.importer.common.AbstractKmLineImport;
import org.dive4elements.river.model.sinfo.BedMobility;
import org.dive4elements.river.model.sinfo.BedMobilityValue;
import org.hibernate.Query;
import org.hibernate.Session;

/**
 * Imported bed mobility value of a river station.
 *
 * @author Matthias Schäfer
 *
 */
public class BedMobilityKmLineImport extends AbstractKmLineImport<BedMobility, BedMobilityValue> {

    /***** FIELDS *****/

    private boolean bedMoving;


    /***** CONSTRUCTOR *****/

    public BedMobilityKmLineImport(final Double km, final boolean bedMoving) {
        super(km.doubleValue());
        this.bedMoving = bedMoving;
    }

    /***** METHODS *****/

    public void setBedMoving(final boolean bedMoving) {
        this.bedMoving = bedMoving;
    }

    @Override
    protected BedMobilityValue queryValueItem(final Session session, final BedMobility parent) {
        final Query query = session.createQuery("FROM BedMobilityValue WHERE (bedMobility=:parent) AND (station=:station)");
        query.setParameter("parent", parent);
        query.setParameter("station", this.station);
        final List rows = query.list();
        if (!rows.isEmpty())
            return (BedMobilityValue) rows.get(0);
        else
            return null;
    }


    @Override
    protected BedMobilityValue createValueItem(final BedMobility parent) {
        return new BedMobilityValue(parent, this.station, this.bedMoving);
    }
}
